Project organisation
====================

Directory layout 
----------------

The python scripts to run analysis can be found in :py:mod:`locpix.scripts`

The python library code can be found in 

* :py:mod:`locpix.preprocessing`
* :py:mod:`locpix.img_processing`
* :py:mod:`locpix.evaluation`
* :py:mod:`locpix.visualisation`
